#!/bin/sh

# The source here is entirely from a wu-ftpd-2.6.* distribution
# EXCEPT for the following:
#	wu-ftpd-2.6.sh		this file -- drives the build
#	wu-ftpd-2.6-patches	the modifications to be applied
#	NLS/en/*		the US English message catalogs
#
# Some of what is installed for ftp remains in the
# .../usr/src/common/cmd/cmd-inet/usr.sbin/in.ftpd/
# regular source tree directory, for various reasons.

set -x

# First configure the thing
[ -f wu-ftpd-2.6-been-configured ] || {
	./configure --host=i386-sco-unixware --build=i686-sco-unixware
	date >wu-ftpd-2.6-been-configured
}

# Then apply the patches (since it also affects generated source)
[ -f wu-ftpd-2.6-been-patched ] || {
	patch -p1 -i wu-ftpd-2.6-patches || {
		echo '@#%$!: ERROR: something failed patching wu-ftpd-2.6' 1>&2
		exit 2
	}
	date >wu-ftpd-2.6-been-patched
}

# The patch file contents is generated by the following:
#: mod='config.h
#: src/Makefile
#: src/access.c
#: src/config.h
#: src/domain.c
#: src/extensions.c
#: src/extensions.h
#: src/ftpcmd.y
#: src/ftpcount.c
#: src/ftpd.c
#: src/ftprestart.c
#: src/ftpshut.c
#: src/getpwnam.c
#: src/glob.c
#: src/hostacc.c
#: src/hostacc.h
#: src/logwtmp.c
#: src/pathnames.h
#: src/popen.c
#: src/private.c
#: src/proto.h
#: src/restrict.c
#: src/routevector.c
#: src/sigfix.c
#: support/getusershell.c'
#: for i in $mod; do
#:    diff -c "wu-ftpd-2.6/$i" "wu-ftpd-mod/$i"
#: done >wu-ftpd-2.6/wu-ftpd-2.6-patches
#
# Where wu-ftpd-mod/ is the directory containing the edited sources.
# Note that this should be done just after the ./configure invocation.
#
# You can easily run this by doing
#	sed -n 's/^#: //p' <wu-ftpd-2.6/wu-ftpd-2.6.sh|sh
# once you've got the directories ready.

# Build the result, strip the utilities, and generate the "en" catalogs
set -e
${MAKE-make} all
${STRIP-strip} bin/*
(cd NLS/en
 for i in *.gen
 do
     cat=`basename "$i" .gen`.cat
     gencat "$cat" <"$i"
 done)

# And install the parts not already handled by the old version still
# found in .../usr/src/common/cmd/cmd-inet/usr.sbin/in.ftpd/.  In
# particular, pipeline, the remaining configuration files, and the
# non-"en" message catalogs.
set +e
sh $INS 555 bin bin $ROOT/$MACH/usr/sbin/ftpcount bin/ftpcount
sh $INS 555 bin bin $ROOT/$MACH/usr/sbin/in.ftpd bin/ftpd
sh $INS 555 bin bin $ROOT/$MACH/usr/sbin/ftprestart bin/ftprestart
sh $INS 555 bin bin $ROOT/$MACH/usr/sbin/ftpshut bin/ftpshut
rm -f $ROOT/$MACH/usr/sbin/ftpwho
ln $ROOT/$MACH/usr/sbin/ftpcount $ROOT/$MACH/usr/sbin/ftpwho

sh $INS 444 bin bin $ROOT/$MACH/etc/inet/ftpservers doc/examples/ftpservers

for i in NLS/en/*.cat NLS/en/*.cat.m
do
    sh $INS 444 bin bin $ROOT/$MACH/usr/lib/locale/en/LC_MESSAGES/"$i" "$i"
done
